#ifndef NT2_INCLUDE_CONSTANTS_MNINE_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MNINE_HPP_INCLUDED

#include <nt2/constant/include/constants/mnine.hpp>

#endif
